Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(126)

Unified Diff: ash/shell_observer.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/shell_observer.h
diff --git a/ash/shell_observer.h b/ash/shell_observer.h
index a98700afff3dd92f099932c9e5b5bde3ab988318..562897028bea6264e3c76b2bf78055e9b6818841 100644
--- a/ash/shell_observer.h
+++ b/ash/shell_observer.h
@@ -50,16 +50,16 @@ class ASH_EXPORT ShellObserver {
// Called after overview mode has ended.
virtual void OnOverviewModeEnded() {}
// Called when the always maximize mode has started. Windows might still
// animate though.
- virtual void OnMaximizeModeStarted() {}
+ virtual void OnTabletModeStarted() {}
- // Called when the maximize mode is about to end.
- virtual void OnMaximizeModeEnding() {}
+ // Called when the tablet mode is about to end.
+ virtual void OnTabletModeEnding() {}
- // Called when the maximize mode has ended. Windows may still be
+ // Called when the tablet mode has ended. Windows may still be
// animating but have been restored.
- virtual void OnMaximizeModeEnded() {}
+ virtual void OnTabletModeEnded() {}
// Called when keyboard is activated/deactivated in |root_window|.
virtual void OnVirtualKeyboardStateChanged(bool activated,
@@ -50,16 +50,16 @@ class ASH_EXPORT ShellObserver {
// Called after overview mode has ended.
virtual void OnOverviewModeEnded() {}
- // Called when the always maximize mode has started. Windows might still
+ // Called when the always tablet mode has started. Windows might still
// animate though.

Powered by Google App Engine
This is Rietveld 408576698